#[non_exhaustive]pub struct EncryptedFileHashes(/* private fields */);events only.Expand description
A map of EncryptedFileHashAlgorithm to the associated EncryptedFileHash.
This type is used to ensure that a supported EncryptedFileHash always matches the
appropriate EncryptedFileHashAlgorithm.
Implementations
Sourceimpl EncryptedFileHashes
impl EncryptedFileHashes
Sourcepub fn new() -> EncryptedFileHashes
pub fn new() -> EncryptedFileHashes
Construct an empty EncryptedFileHashes.
Sourcepub fn with_sha256(hash: [u8; 32]) -> EncryptedFileHashes
pub fn with_sha256(hash: [u8; 32]) -> EncryptedFileHashes
Construct an EncryptedFileHashes that includes the given SHA-256 hash.
Sourcepub fn insert(&mut self, hash: EncryptedFileHash) -> Option<EncryptedFileHash>
pub fn insert(&mut self, hash: EncryptedFileHash) -> Option<EncryptedFileHash>
Insert the given EncryptedFileHash.
If a map with the same EncryptedFileHashAlgorithm was already present, it is returned.
Methods from Deref<Target = BTreeMap<EncryptedFileHashAlgorithm, EncryptedFileHash>>
1.0.0 · Sourcepub fn get<Q>(&self, key: &Q) -> Option<&V>
Available on crate feature api and (crate features client-api-c or client-api-s) and (crate features client or server) only.
pub fn get<Q>(&self, key: &Q) -> Option<&V>
api and (crate features client-api-c or client-api-s) and (crate features client or server) only.Returns a reference to the value corresponding to the key.
The key may be any borrowed form of the map’s key type, but the ordering on the borrowed form must match the ordering on the key type.
Examples
use std::collections::BTreeMap;
let mut map = BTreeMap::new();
map.insert(1, "a");
assert_eq!(map.get(&1), Some(&"a"));
assert_eq!(map.get(&2), None);1.40.0 · Sourcepub fn get_key_value<Q>(&self, k: &Q) -> Option<(&K, &V)>
Available on crate feature api and (crate features client-api-c or client-api-s) and (crate features client or server) only.
pub fn get_key_value<Q>(&self, k: &Q) -> Option<(&K, &V)>
api and (crate features client-api-c or client-api-s) and (crate features client or server) only.Returns the key-value pair corresponding to the supplied key. This is potentially useful:
- for key types where non-identical keys can be considered equal;
- for getting the
&Kstored key value from a borrowed&Qlookup key; or - for getting a reference to a key with the same lifetime as the collection.
The supplied key may be any borrowed form of the map’s key type, but the ordering on the borrowed form must match the ordering on the key type.
Examples
use std::cmp::Ordering;
use std::collections::BTreeMap;
#[derive(Clone, Copy, Debug)]
struct S {
id: u32,
name: &'static str, // ignored by equality and ordering operations
}
impl PartialEq for S {
fn eq(&self, other: &S) -> bool {
self.id == other.id
}
}
impl Eq for S {}
impl PartialOrd for S {
fn partial_cmp(&self, other: &S) -> Option<Ordering> {
self.id.partial_cmp(&other.id)
}
}
impl Ord for S {
fn cmp(&self, other: &S) -> Ordering {
self.id.cmp(&other.id)
}
}
let j_a = S { id: 1, name: "Jessica" };
let j_b = S { id: 1, name: "Jess" };
let p = S { id: 2, name: "Paul" };
assert_eq!(j_a, j_b);
let mut map = BTreeMap::new();
map.insert(j_a, "Paris");
assert_eq!(map.get_key_value(&j_a), Some((&j_a, &"Paris")));
assert_eq!(map.get_key_value(&j_b), Some((&j_a, &"Paris"))); // the notable case
assert_eq!(map.get_key_value(&p), None);1.66.0 · Sourcepub fn first_key_value(&self) -> Option<(&K, &V)>where
K: Ord,
Available on crate feature api and (crate features client-api-c or client-api-s) and (crate features client or server) only.
pub fn first_key_value(&self) -> Option<(&K, &V)>where
K: Ord,
api and (crate features client-api-c or client-api-s) and (crate features client or server) only.Returns the first key-value pair in the map. The key in this pair is the minimum key in the map.
Examples
use std::collections::BTreeMap;
let mut map = BTreeMap::new();
assert_eq!(map.first_key_value(), None);
map.insert(1, "b");
map.insert(2, "a");
assert_eq!(map.first_key_value(), Some((&1, &"b")));1.66.0 · Sourcepub fn last_key_value(&self) -> Option<(&K, &V)>where
K: Ord,
Available on crate feature api and (crate features client-api-c or client-api-s) and (crate features client or server) only.
pub fn last_key_value(&self) -> Option<(&K, &V)>where
K: Ord,
api and (crate features client-api-c or client-api-s) and (crate features client or server) only.Returns the last key-value pair in the map. The key in this pair is the maximum key in the map.
Examples
use std::collections::BTreeMap;
let mut map = BTreeMap::new();
map.insert(1, "b");
map.insert(2, "a");
assert_eq!(map.last_key_value(), Some((&2, &"a")));1.0.0 · Sourcepub fn contains_key<Q>(&self, key: &Q) -> bool
Available on crate feature api and (crate features client-api-c or client-api-s) and (crate features client or server) only.
pub fn contains_key<Q>(&self, key: &Q) -> bool
api and (crate features client-api-c or client-api-s) and (crate features client or server) only.Returns true if the map contains a value for the specified key.
The key may be any borrowed form of the map’s key type, but the ordering on the borrowed form must match the ordering on the key type.
Examples
use std::collections::BTreeMap;
let mut map = BTreeMap::new();
map.insert(1, "a");
assert_eq!(map.contains_key(&1), true);
assert_eq!(map.contains_key(&2), false);1.17.0 · Sourcepub fn range<T, R>(&self, range: R) -> Range<'_, K, V>
Available on crate feature api and (crate features client-api-c or client-api-s) and (crate features client or server) only.
pub fn range<T, R>(&self, range: R) -> Range<'_, K, V>
api and (crate features client-api-c or client-api-s) and (crate features client or server) only.Constructs a double-ended iterator over a sub-range of elements in the map.
The simplest way is to use the range syntax min..max, thus range(min..max) will
yield elements from min (inclusive) to max (exclusive).
The range may also be entered as (Bound<T>, Bound<T>), so for example
range((Excluded(4), Included(10))) will yield a left-exclusive, right-inclusive
range from 4 to 10.
Panics
Panics if range start > end.
Panics if range start == end and both bounds are Excluded.
Examples
use std::collections::BTreeMap;
use std::ops::Bound::Included;
let mut map = BTreeMap::new();
map.insert(3, "a");
map.insert(5, "b");
map.insert(8, "c");
for (&key, &value) in map.range((Included(&4), Included(&8))) {
println!("{key}: {value}");
}
assert_eq!(Some((&5, &"b")), map.range(4..).next());1.0.0 · Sourcepub fn iter(&self) -> Iter<'_, K, V>
Available on crate feature api and (crate features client-api-c or client-api-s) and (crate features client or server) only.
pub fn iter(&self) -> Iter<'_, K, V>
api and (crate features client-api-c or client-api-s) and (crate features client or server) only.Gets an iterator over the entries of the map, sorted by key.
Examples
use std::collections::BTreeMap;
let mut map = BTreeMap::new();
map.insert(3, "c");
map.insert(2, "b");
map.insert(1, "a");
for (key, value) in map.iter() {
println!("{key}: {value}");
}
let (first_key, first_value) = map.iter().next().unwrap();
assert_eq!((*first_key, *first_value), (1, "a"));1.0.0 · Sourcepub fn keys(&self) -> Keys<'_, K, V>
Available on crate feature api and (crate features client-api-c or client-api-s) and (crate features client or server) only.
pub fn keys(&self) -> Keys<'_, K, V>
api and (crate features client-api-c or client-api-s) and (crate features client or server) only.Gets an iterator over the keys of the map, in sorted order.
Examples
use std::collections::BTreeMap;
let mut a = BTreeMap::new();
a.insert(2, "b");
a.insert(1, "a");
let keys: Vec<_> = a.keys().cloned().collect();
assert_eq!(keys, [1, 2]);1.0.0 · Sourcepub fn values(&self) -> Values<'_, K, V>
Available on crate feature api and (crate features client-api-c or client-api-s) and (crate features client or server) only.
pub fn values(&self) -> Values<'_, K, V>
api and (crate features client-api-c or client-api-s) and (crate features client or server) only.Gets an iterator over the values of the map, in order by key.
Examples
use std::collections::BTreeMap;
let mut a = BTreeMap::new();
a.insert(1, "hello");
a.insert(2, "goodbye");
let values: Vec<&str> = a.values().cloned().collect();
assert_eq!(values, ["hello", "goodbye"]);1.0.0 · Sourcepub fn len(&self) -> usize
Available on crate feature api and (crate features client-api-c or client-api-s) and (crate features client or server) only.
pub fn len(&self) -> usize
api and (crate features client-api-c or client-api-s) and (crate features client or server) only.Returns the number of elements in the map.
Examples
use std::collections::BTreeMap;
let mut a = BTreeMap::new();
assert_eq!(a.len(), 0);
a.insert(1, "a");
assert_eq!(a.len(), 1);1.0.0 · Sourcepub fn is_empty(&self) -> bool
Available on crate feature api and (crate features client-api-c or client-api-s) and (crate features client or server) only.
pub fn is_empty(&self) -> bool
api and (crate features client-api-c or client-api-s) and (crate features client or server) only.Returns true if the map contains no elements.
Examples
use std::collections::BTreeMap;
let mut a = BTreeMap::new();
assert!(a.is_empty());
a.insert(1, "a");
assert!(!a.is_empty());Sourcepub fn lower_bound<Q>(&self, bound: Bound<&Q>) -> Cursor<'_, K, V>
🔬This is a nightly-only experimental API. (btree_cursors)Available on crate feature api and (crate features client-api-c or client-api-s) and (crate features client or server) only.
pub fn lower_bound<Q>(&self, bound: Bound<&Q>) -> Cursor<'_, K, V>
btree_cursors)api and (crate features client-api-c or client-api-s) and (crate features client or server) only.Returns a Cursor pointing at the gap before the smallest key
greater than the given bound.
Passing Bound::Included(x) will return a cursor pointing to the
gap before the smallest key greater than or equal to x.
Passing Bound::Excluded(x) will return a cursor pointing to the
gap before the smallest key greater than x.
Passing Bound::Unbounded will return a cursor pointing to the
gap before the smallest key in the map.
Examples
#![feature(btree_cursors)]
use std::collections::BTreeMap;
use std::ops::Bound;
let map = BTreeMap::from([
(1, "a"),
(2, "b"),
(3, "c"),
(4, "d"),
]);
let cursor = map.lower_bound(Bound::Included(&2));
assert_eq!(cursor.peek_prev(), Some((&1, &"a")));
assert_eq!(cursor.peek_next(), Some((&2, &"b")));
let cursor = map.lower_bound(Bound::Excluded(&2));
assert_eq!(cursor.peek_prev(), Some((&2, &"b")));
assert_eq!(cursor.peek_next(), Some((&3, &"c")));
let cursor = map.lower_bound(Bound::Unbounded);
assert_eq!(cursor.peek_prev(), None);
assert_eq!(cursor.peek_next(), Some((&1, &"a")));Sourcepub fn upper_bound<Q>(&self, bound: Bound<&Q>) -> Cursor<'_, K, V>
🔬This is a nightly-only experimental API. (btree_cursors)Available on crate feature api and (crate features client-api-c or client-api-s) and (crate features client or server) only.
pub fn upper_bound<Q>(&self, bound: Bound<&Q>) -> Cursor<'_, K, V>
btree_cursors)api and (crate features client-api-c or client-api-s) and (crate features client or server) only.Returns a Cursor pointing at the gap after the greatest key
smaller than the given bound.
Passing Bound::Included(x) will return a cursor pointing to the
gap after the greatest key smaller than or equal to x.
Passing Bound::Excluded(x) will return a cursor pointing to the
gap after the greatest key smaller than x.
Passing Bound::Unbounded will return a cursor pointing to the
gap after the greatest key in the map.
Examples
#![feature(btree_cursors)]
use std::collections::BTreeMap;
use std::ops::Bound;
let map = BTreeMap::from([
(1, "a"),
(2, "b"),
(3, "c"),
(4, "d"),
]);
let cursor = map.upper_bound(Bound::Included(&3));
assert_eq!(cursor.peek_prev(), Some((&3, &"c")));
assert_eq!(cursor.peek_next(), Some((&4, &"d")));
let cursor = map.upper_bound(Bound::Excluded(&3));
assert_eq!(cursor.peek_prev(), Some((&2, &"b")));
assert_eq!(cursor.peek_next(), Some((&3, &"c")));
let cursor = map.upper_bound(Bound::Unbounded);
assert_eq!(cursor.peek_prev(), Some((&4, &"d")));
assert_eq!(cursor.peek_next(), None);Trait Implementations
Sourceimpl Clone for EncryptedFileHashes
impl Clone for EncryptedFileHashes
Sourcefn clone(&self) -> EncryptedFileHashes
fn clone(&self) -> EncryptedFileHashes
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for EncryptedFileHashes
impl Debug for EncryptedFileHashes
Sourceimpl Default for EncryptedFileHashes
impl Default for EncryptedFileHashes
Sourcefn default() -> EncryptedFileHashes
fn default() -> EncryptedFileHashes
Sourceimpl Deref for EncryptedFileHashes
impl Deref for EncryptedFileHashes
Sourcetype Target = BTreeMap<EncryptedFileHashAlgorithm, EncryptedFileHash>
type Target = BTreeMap<EncryptedFileHashAlgorithm, EncryptedFileHash>
Sourceimpl<'de> Deserialize<'de> for EncryptedFileHashes
impl<'de> Deserialize<'de> for EncryptedFileHashes
Sourcefn deserialize<D>(
deserializer: D,
) -> Result<EncryptedFileHashes, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
fn deserialize<D>(
deserializer: D,
) -> Result<EncryptedFileHashes, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
Sourceimpl Extend<EncryptedFileHash> for EncryptedFileHashes
impl Extend<EncryptedFileHash> for EncryptedFileHashes
Sourcefn extend<T>(&mut self, iter: T)where
T: IntoIterator<Item = EncryptedFileHash>,
fn extend<T>(&mut self, iter: T)where
T: IntoIterator<Item = EncryptedFileHash>,
Sourcefn extend_one(&mut self, item: A)
fn extend_one(&mut self, item: A)
extend_one)Sourcefn extend_reserve(&mut self, additional: usize)
fn extend_reserve(&mut self, additional: usize)
extend_one)Sourceimpl FromIterator<EncryptedFileHash> for EncryptedFileHashes
impl FromIterator<EncryptedFileHash> for EncryptedFileHashes
Sourcefn from_iter<T>(iter: T) -> EncryptedFileHasheswhere
T: IntoIterator<Item = EncryptedFileHash>,
fn from_iter<T>(iter: T) -> EncryptedFileHasheswhere
T: IntoIterator<Item = EncryptedFileHash>,
Sourceimpl IntoIterator for EncryptedFileHashes
impl IntoIterator for EncryptedFileHashes
Sourcetype Item = EncryptedFileHash
type Item = EncryptedFileHash
Sourcetype IntoIter = IntoValues<EncryptedFileHashAlgorithm, EncryptedFileHash>
type IntoIter = IntoValues<EncryptedFileHashAlgorithm, EncryptedFileHash>
Sourcefn into_iter(self) -> <EncryptedFileHashes as IntoIterator>::IntoIter
fn into_iter(self) -> <EncryptedFileHashes as IntoIterator>::IntoIter
Sourceimpl Serialize for EncryptedFileHashes
impl Serialize for EncryptedFileHashes
Sourcefn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
fn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,